@@ -1,5 +1,5 @@
 package Git::ObjectStore;
-$Git::ObjectStore::VERSION = '0.005';
+$Git::ObjectStore::VERSION = '0.006';
 use strict;
 use warnings;
 
@@ -52,9 +52,22 @@ sub new
     }
 
     my $repo = $self->{'repo'} = Git::Raw::Repository->open($repodir);
+    my $objdir = catfile($repodir, 'objects');
+
+    # We do not use loose backend, so we explicitly exclude it from ODB.
+    {
+        my $odb = Git::Raw::Odb->new();
+        $odb->add_backend(Git::Raw::Odb::Backend::Pack->new($objdir), 10);
+        $repo->odb($odb);
+    }
 
     if ( $self->{'writer'} ) {
 
+        # in-memory store that will write a single pack file for all objects
+        $self->{'packdir'} = catfile($objdir, 'pack');
+        my $mempack = $self->{'mempack'} = Git::Raw::Mempack->new;
+        $repo->odb->add_backend($mempack, 99);
+
         my $branch = Git::Raw::Branch->lookup($repo, $branchname, 1);
 
         if ( not defined($branch) ) {
@@ -71,11 +84,6 @@ sub new
 
         croak('expected a branch') unless defined($branch);
 
-        # in-memory store that will write a single pack file for all objects
-        $self->{'packdir'} = catfile($repodir, 'objects', 'pack');
-        my $mempack = $self->{'mempack'} = Git::Raw::Mempack->new;
-        $repo->odb->add_backend($mempack, 99);
-
         # in-memory index for preparing a commit
         my $index = Git::Raw::Index->new();
 
@@ -308,6 +316,8 @@ sub create_commit_and_packfile
     if( $self->create_commit($msg) ) {
         $self->write_packfile();
         return 1;
+    } elsif ( defined($self->{'created_init_commit'}) ) {
+        $self->write_packfile();
     }
 
     return 0;
@@ -450,7 +460,7 @@ Git::ObjectStore - abstraction layer for Git::Raw and libgit2
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -619,7 +629,9 @@ the changes are written to persistent storage.
 
 This method combines C<create_commit()> and C<write_packfile>. The
 packfile is only written if there is a change in the content. The method
-returns true if any changes were detected.
+returns true if any changes were detected. If it's a new branch and it
+only contains the empty initial commit, a packfile is written and the
+method returns false.
 
 =head2 recursive_read($path, $callback, $no_content)
 
